<?php

/*
 * Implements hook_install_tasks_alter()
 */
function openaid_install_tasks_alter(&$tasks, $install_state) {
  // Add a step as the second install step
  if (!isset($tasks['install_verify_site_dir']) && !isset($tasks['install_verify_apachesolr'])) {
    // keep the install profile task
    $tasks1 = array_slice($tasks, 0, 1, TRUE);
    // add custom tasks
    $tasks2 = array(
      'install_verify_site_dir' => array(
        'display_name' => st('Verify site directory'),
        'display' => 1,
        'function' => 'openaid_install_verify_site_dir',
      ),
      // 'install_verify_apachesolr' => array(
      //   'display_name' => st('Verify Apache Solr'),
      //   'display' => 1,
      //   'function' => 'openaid_install_verify_apachesolr',
      // ),
    );
    // get remaining tasks without the finished step
    $tasks3 = array_slice($tasks, 1, -1, TRUE);
    // substitute our own finished step
    $tasks4 = array(
      'install_finished' => array(
        'display_name' => st('Finished Installation'),
        'display' => 1,
        'function' => 'openaid_install_finished',
      ),
    );

    $tasks = array_merge($tasks1, $tasks2, $tasks3, $tasks4);
    
  } // if no verify step
} // openaid_install_tasks_alter()

function openaid_install_verify_site_dir(&$install_state) {
  // get the url
  $domain = $_SERVER['SERVER_NAME'];
  $dir = DRUPAL_ROOT . '/sites/' . $domain;

  if (!file_exists($dir)) {
    return '<p>' . st('Before installing, you must first create a site directory. Please create a directory at %dir', array('%dir' => $dir)) . '</p>';
  } // if no dir

  if (!is_readable($dir)) {
    return '<p>' . st('The site directory at %dir is not readable. Please correct the permissions.', array('%dir' => $dir)) . '</p>';
  } // if no dir

  if (!is_writable($dir)) {
    return '<p>' . st('The site directory at %dir is not writable. Please correct the permissions.', array('%dir' => $dir)) . '</p>';
  } // if no dir
} // openaid_install_verify_site_dir()

function openaid_install_verify_apachesolr(&$install_state) {
  if (!isset($_COOKIE['has_solr']) || !$_COOKIE['has_solr']) {
    // create the solr address
    $domain = $_SERVER['SERVER_NAME'];
    $solr = 'tcp://' . $domain . ':8983/solr';

    // test if the server can reach the solr server
    $has_solr = @stream_socket_client($solr, $errno, $errstr, 15.0);
    if (!$has_solr) {
      // generate the message
      $return = '<p>' . st('There was a problem connecting to the Apache Solr server at %solr. Please verify that you have a valid Apache Solr server running.', array('%solr' => $solr)) . '</p>';
      $return .= '<p>' . st('If you have installed Apache Solr at a different location, you may <a href="#" onclick="document.cookie=\'has_solr=1\';location.reload();">continue the installation</a>', array('!install' => $install)) . '</p>';
      return $return;
    } // if has solr
  } // if no solr bypass
} // openaid_install_verify_site_dir()

function openaid_install_finished(&$install_state) {
  drupal_set_title(st('@drupal installation complete', array('@drupal' => drupal_install_profile_distribution_name())), PASS_THROUGH);
  $messages = drupal_set_message();
  $output = '<p>' . st('Congratulations, you installed @drupal!', array('@drupal' => drupal_install_profile_distribution_name())) . '</p>';
  $output .= '<p>' . (isset($messages['error']) ? st('Review the messages above before enabling <a href="@url">the features of your new site</a>.', array('@url' => url('admin/structure/features'))) : st('<a href="@url">Visit your new site and enable features</a>.', array('@url' => url('admin/structure/features')))) . '</p>';   
  $output .= '<p>' . st('If you need mapping features, you will need to manually install the <a href="@url">geofield</a> module, as it requires 3rd party libraries not whitelisted at the time of this release.', array('@url' => url('http://drupal.org/project/geofield'))) . '</p>';   

  // Flush all caches to ensure that any full bootstraps during the installer
  // do not leave stale cached data, and that any content types or other items
  // registered by the install profile are registered correctly.
  drupal_flush_all_caches();

  // Remember the profile which was used.
  variable_set('install_profile', drupal_get_profile());

  // Install profiles are always loaded last
  db_update('system')
    ->fields(array('weight' => 1000))
    ->condition('type', 'module')
    ->condition('name', drupal_get_profile())
    ->execute();

  // Cache a fully-built schema.
  drupal_get_schema(NULL, TRUE);

  // Run cron to populate update status tables (if available) so that users
  // will be warned if they've installed an out of date Drupal version.
  // Will also trigger indexing of profile-supplied content or feeds.
  drupal_cron_run();

  return $output;

} // openaid_install_verify_site_dir()
